BeforeLoginAuth - 登录前使用的基础验证方式
==========================================

..  automodule:: zhihu_oauth.oauth.before_login_auth
    :members:
    :undoc-members:
    :special-members: __init__, __call__
